<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl_NL">
<context>
    <name>GPIOConfiguration</name>
    <message>
        <location filename="gpioconfiguration.ui" line="33"/>
        <source>Configure GPIO Plugin</source>
        <translation>Configureer GPIO Plugin</translation>
    </message>
    <message>
        <location filename="gpioconfiguration.ui" line="46"/>
        <source>Selected chip</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="gpioconfiguration.ui" line="57"/>
        <source>GPIO Number</source>
        <translation>GPIO Nummer</translation>
    </message>
    <message>
        <location filename="gpioconfiguration.ui" line="62"/>
        <source>Usage</source>
        <translation>Gebruik</translation>
    </message>
    <message>
        <location filename="gpioconfiguration.ui" line="67"/>
        <source>Channel number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="gpioconfiguration.cpp" line="79"/>
        <source>Not used</source>
        <translation>Niet in gebruik</translation>
    </message>
    <message>
        <location filename="gpioconfiguration.cpp" line="80"/>
        <source>Input</source>
        <translation>Input</translation>
    </message>
    <message>
        <location filename="gpioconfiguration.cpp" line="81"/>
        <source>Output</source>
        <translation>Output</translation>
    </message>
</context>
<context>
    <name>GPIOPlugin</name>
    <message>
        <location filename="gpioplugin.cpp" line="97"/>
        <source>This plugin provides input/output on GPIO PINs.</source>
        <translation>Deze plugin verzorgt input/output op GPIO PINs.</translation>
    </message>
</context>
</TS>
